@@ -2,11 +2,10 @@ import requests
 
 
 class BaseClient(object):
-    def __init__(self, token, ttl):
+    def __init__(self, token):
         from version import __version__
 
         self.token = token
-        self.ttl = ttl
         self.version = __version__
 
     @property
